@@ -2,20 +2,18 @@ from __future__ import annotations
 from pathlib import PosixPath, WindowsPath, _NormalAccessor, \
   Path, PurePath, _ignore_error
 from typing import Optional, List, Union, AsyncIterable
-from os import stat_result
+from os import stat_result, PathLike
 from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, \
   S_ISCHR, S_ISFIFO
 import os
 
-from aiofile import AIOFile
-from aiofiles import os as async_os
-from aiofiles.os import wrap as method_as_method_coro, \
-  wrap as func_as_corofunc
+from anyio import open_file
 
 from .selectors import _make_selector
 from .flavours import _async_windows_flavour, _async_posix_flavour
-from .wrap import coro_as_method_coro, func_as_method_coro, to_thread
-from .handle import IterableAIOFile, read_full_file
+from .wrap import coro_as_method_coro, func_as_method_coro, to_thread, \
+  method_as_method_coro, func_to_async_func
+from .handle import IterableAIOFile
 from .scandir import EntryWrapper, scandir_async
 from .types import Final, Literal, FileMode
 
@@ -25,12 +23,14 @@ ON_ERRORS: Final[str] = 'ignore'
 NEWLINE: Final[str] = '\n'
 
 
-getcwd = func_as_corofunc(os.getcwd)
-close = func_as_corofunc(os.close)
+Paths = Union[Path, PathLike, str]
+
+
+close = func_to_async_func(os.close)
 
 
 class _AsyncAccessor(_NormalAccessor):
-  stat = coro_as_method_coro(async_os.stat)
+  stat = func_as_method_coro(os.stat)
   lstat = func_as_method_coro(os.lstat)
   open = func_as_method_coro(os.open)
   listdir = func_as_method_coro(os.listdir)
@@ -39,14 +39,14 @@ class _AsyncAccessor(_NormalAccessor):
   if hasattr(_NormalAccessor, 'lchmod'):
     lchmod = method_as_method_coro(_NormalAccessor.lchmod)
 
-  mkdir = coro_as_method_coro(async_os.mkdir)
+  mkdir = func_as_method_coro(os.mkdir)
   unlink = func_as_method_coro(os.unlink)
 
   if hasattr(_NormalAccessor, 'link'):
     link = method_as_method_coro(_NormalAccessor.link)
 
-  rmdir = coro_as_method_coro(async_os.rmdir)
-  rename = coro_as_method_coro(async_os.rename)
+  rmdir = func_as_method_coro(os.rmdir)
+  rename = func_as_method_coro(os.rename)
   replace = func_as_method_coro(os.replace)
 
   symlink = staticmethod(
@@ -55,7 +55,7 @@ class _AsyncAccessor(_NormalAccessor):
 
   utime = func_as_method_coro(os.utime)
   readlink = method_as_method_coro(_NormalAccessor.readlink)
-  remove = coro_as_method_coro(async_os.remove)
+  remove = func_as_method_coro(os.remove)
 
   async def owner(self, path: str) -> str:
     try:
@@ -146,7 +146,7 @@ class AsyncPath(Path, AsyncPurePath):
     errors: Optional[str] = ON_ERRORS,
     newline: Optional[str] = NEWLINE,
   ) -> IterableAIOFile:
-    return IterableAIOFile(
+    return open_file(
       self._path,
       mode,
       encoding=encoding,
@@ -371,11 +371,11 @@ class AsyncPath(Path, AsyncPurePath):
       #return False
 
   @classmethod
-  async def cwd(cls: type) -> str:
+  def cwd(cls: type) -> str:
     """Return a new path pointing to the current working directory
     (as returned by os.getcwd()).
     """
-    cwd: str = await getcwd()
+    cwd: str = os.getcwd()
     return cls(cwd)
 
   @classmethod
@@ -388,10 +388,16 @@ class AsyncPath(Path, AsyncPurePath):
 
     return cls(homedir)
 
-  async def samefile(self, other_path: Union[AsyncPath, Path]) -> bool:
+  async def samefile(
+    self,
+    other_path: Union[AsyncPath, Paths]
+  ) -> bool:
     """Return whether other_path is the same or not as this file
     (as returned by os.path.samefile()).
     """
+    if isinstance(other_path, Paths.__args__):
+      other_path = AsyncPath(other_path)
+
     if isinstance(other_path, AsyncPath):
       try:
         other_st = await other_path.stat()
@@ -456,7 +462,7 @@ class AsyncPath(Path, AsyncPurePath):
     async for p in selector.select_from(self):
       yield p
 
-  async def absolute(self) -> AsyncPath:
+  def absolute(self) -> AsyncPath:
     """Return an absolute version of this path.  This function works
     even if the path doesn't point to anything.
     No normalization is done, i.e. all '.' and '..' will be kept along.
@@ -467,7 +473,7 @@ class AsyncPath(Path, AsyncPurePath):
         return self
     # FIXME this must defer to the specific flavour (and, under Windows,
     # use nt._getfullpathname())
-    obj = self._from_parts([await getcwd()] + self._parts, init=False)
+    obj = self._from_parts([os.getcwd()] + self._parts, init=False)
     obj._init(template=self)
     return obj
 
